@@ -129,9 +129,9 @@ int main(int argc, char **argv)
                     case QGpgME::CryptoConfigEntry::ArgType_LDAPURL: {
                         // (marc) if an entry isn't optional, you have to unset it for the default to take effect, so this Q_ASSERT is wrong:
                         // Q_ASSERT( entry->isOptional() ); // empty lists must be allowed (see https://www.intevation.de/roundup/aegypten/issue121)
-                        QList<QUrl> urls = entry->urlValueList();
+                        const QList<QUrl> urls = entry->urlValueList();
                         cout << " url values ";
-                        Q_FOREACH (const QUrl &url, urls) {
+                        for (const QUrl &url : urls) {
                             cout << url.toString().toLocal8Bit().constData() << " ";
                         }
                         cout << endl;
@@ -314,9 +314,9 @@ int main(int argc, char **argv)
         if (entry) {
             Q_ASSERT(entry->argType() == QGpgME::CryptoConfigEntry::ArgType_LDAPURL);
             Q_ASSERT(entry->isList());
-            QList<QUrl> val = entry->urlValueList();
+            const QList<QUrl> val = entry->urlValueList();
             cout << "URL list initially: ";
-            Q_FOREACH (const QUrl &url, val) {
+            for (const QUrl &url : val) {
                 cout << url.toString().toLocal8Bit().constData() << ", ";
             }
             cout << endl;
@@ -345,9 +345,9 @@ int main(int argc, char **argv)
             Q_ASSERT(entry->argType() == QGpgME::CryptoConfigEntry::ArgType_LDAPURL);
             Q_ASSERT(entry->isList());
             // Get QUrl form
-            QList<QUrl> newlst = entry->urlValueList();
+            const QList<QUrl> newlst = entry->urlValueList();
             cout << "URL list now: ";
-            Q_FOREACH (const QUrl &url, newlst) {
+            for (const QUrl &url : newlst) {
                 cout << url.toString().toLocal8Bit().constData() << endl;
             }
             cout << endl;
