@@ -682,7 +682,7 @@ QString Formatting::importMetaData(const Import &import, const QStringList &ids)
     } else
         return result + QLatin1Char('\n') +
                i18n("This certificate was imported from the following sources:") + QLatin1Char('\n') +
-               ids.join(QStringLiteral("\n"));
+               ids.join(QLatin1Char('\n'));
 }
 
 QString Formatting::importMetaData(const Import &import)
@@ -718,7 +718,7 @@ QString Formatting::importMetaData(const Import &import)
 
     return results.empty()
            ? i18n("The import contained no new data for this certificate. It is unchanged.")
-           : results.join(QStringLiteral("\n"));
+           : results.join(QLatin1Char('\n'));
 }
 
 //
@@ -750,7 +750,7 @@ QString Formatting::usageString(const Subkey &sub)
 
 QString Formatting::summaryLine(const Key &key)
 {
-    return keyToString(key) + QStringLiteral(" ") +
+    return keyToString(key) + QLatin1Char(' ') +
            i18nc("First arg is the Key Protocol OpenPGP or S/MIME, second arg is the creation date.",
                  "(%1 - created: %2)", displayName(key.protocol()) ,
                  Formatting::creationDateString(key));
